"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const got_1 = __importDefault(require("got"));
const cheerio = __importStar(require("cheerio"));
const index_js_1 = require("../types/index.js");
const lyrics_v2_js_1 = require("../types/lyrics-v2.js");
/**
 * Scrape from https://genius.com
 */
async function lyricsv2(query) {
    index_js_1.LyricsArgsSchema.parse(arguments);
    const search = await (0, got_1.default)(`https://genius.com/api/search/multi?per_page=5&q=${encodeURIComponent(query).replace(/%20/, '+')}`).json();
    const json = lyrics_v2_js_1.LyricsV2SearchResponseSchema.parse(search);
    const sections = json.response.sections.find((section) => section.type === 'song');
    const { api_path, url } = sections.hits[0].result;
    const [data, html] = await Promise.all([
        (0, got_1.default)(`https://genius.com/api${api_path}`).json(),
        (0, got_1.default)(url).text()
    ]);
    const metadata = lyrics_v2_js_1.LyricsV2MetadataResponseSchema.parse(data);
    const { id, full_title, artist_names, album, header_image_url, header_image_thumbnail_url, description_preview, release_date_components, spotify_uuid, youtube_url, soundcloud_url, apple_music_player_url } = metadata.response.song;
    const $ = cheerio.load(html);
    const $lyrics = $('#lyrics-root > div[data-lyrics-container="true"]');
    const lyrics = ($lyrics.find('a').length ?
        //  The lyric has meaning
        $lyrics.find('a').map(function () {
            const $el = $(this);
            const url = encodeURI('https://genius.com' + $el.attr('href'));
            const $span = $el.find('span');
            // https://github.com/cheeriojs/cheerio/issues/839#issuecomment-205077830
            const html = $span.html().replace(/<br>/g, '\n');
            const text = $span.html(html).text().trim();
            if (!text)
                return false;
            return {
                type: /\[.*?\]/.test(text) ? 'header' : 'lyric',
                url,
                text
            };
        }).toArray()
        // Only lyric 
        : $lyrics.html().replace(/<br>/g, '\n').split('\n').map((text) => {
            if (!text)
                return false;
            return {
                type: /\[.*?\]/.test(text) ? 'header' : 'lyric',
                text: text.trim()
            };
        })).filter(Boolean);
    const result = {
        id,
        title: full_title,
        url,
        artist: artist_names,
        album: album.name,
        albumCover: header_image_url || header_image_thumbnail_url,
        release: new Date(release_date_components.year, release_date_components.month - 1, release_date_components.day).toISOString(),
        description: description_preview,
        ...(spotify_uuid ? { spotify: `https://open.spotify.com/track/${spotify_uuid}` } : {}),
        youtube: youtube_url,
        soundcloud: soundcloud_url,
        appleMusicPlayer: apple_music_player_url,
        lyrics
    };
    return lyrics_v2_js_1.LyricsV2Schema.parse(result);
}
exports.default = lyricsv2;
