"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cheerio = __importStar(require("cheerio"));
const got_1 = __importDefault(require("got"));
const wikipedia_js_1 = require("../types/wikipedia.js");
async function wikipedia(query, lang = 'id') {
    wikipedia_js_1.WikipediaArgsSchema.parse(arguments);
    const html = await getHtml(lang, query);
    const $ = cheerio.load(html);
    const title = $('#firstHeading > i').text().trim();
    const images = $('.infobox-image span[typeof="mw:File"] img[src]').map(function () {
        const $img = $(this);
        const url = $img.attr('src') || $img.attr('srcset');
        return getImgLink(url);
    }).toArray();
    const articles = [];
    let end = false;
    let start = false;
    $('#mw-content-text > div.mw-parser-output')
        .children()
        .map(function () {
        if (/p|h[2-4]|div/.test(this.name) && !end) {
            let text = '';
            const h = /h[2-4]/.test(this.name);
            const div = /div/.test(this.name);
            const el = $(this);
            if (h &&
                /referen|Примечания|Notes_et_références/i.test(el.find('span.mw-headline').attr('id'))) {
                return (end = true);
            }
            const math = $(this).find('span.mwe-math-element');
            if (math.length) {
                math.replaceWith($(`<span>${math
                    .text()
                    .trim()
                    .replace(/(.*displaystyle.*|\\n)/, '')}</span>`));
            }
            if (div &&
                el.hasClass('thumb') &&
                el.find('div.thumbinner > a > img[src]').length) {
                text = getImgLink(el.find('div.thumbinner > a > img[src]').attr('src'));
            }
            else if (div && el.find('div > ol > li[id]').length) {
                el.find('div > ol > li[id]').each(function () {
                    text += $(this).text().trim() + '\n';
                });
            }
            else
                text = el.text().trim();
            if (!start && this.name === 'p' && !end && text)
                start = true;
            if (text && start && !el.find('div > ul > li').length) {
                articles.push((h ? '\n' : '') + text);
            }
        }
        return true;
    });
    const res = {
        title,
        images,
        articles: articles.join('\n\n')
    };
    return wikipedia_js_1.WikipediaSchema.parse(res);
}
exports.default = wikipedia;
function isSupportLang(lang) {
    return ['en', 'id'].includes(lang);
}
async function getHtml(lang, query) {
    query = encodeURIComponent(query.trim());
    const defaultLink = `https://${isSupportLang(lang) ? lang : 'id'}.wikipedia.org`;
    let res = await (0, got_1.default)(defaultLink + '/wiki/' + query);
    if (!(res.statusCode === 404))
        return res.body;
    const link = `${defaultLink}/w/index.php?${lang === 'id'
        ? `title=Istimewa:Pencarian&search=${query}&fulltext=1&ns0=1`
        : `search=${query}&title=Special:Search&profile=advanced&fulltext=1&ns0=1`}`;
    res = await (0, got_1.default)(link);
    const html = res.body;
    const $ = cheerio.load(html);
    const results = [];
    $('ul.mw-search-results > li.mw-search-result').each(function () {
        var _a;
        const link = (_a = $(this)
            .find('div.mw-search-result-heading > a[href]')
            .attr('href')) === null || _a === void 0 ? void 0 : _a.trim();
        if (link)
            results.push(encodeURI(link));
    });
    if (results[0])
        return (await (0, got_1.default)(defaultLink + results[0])).body;
    throw new Error('404 Not Found!!');
}
function getImgLink(link = '') {
    if (!/https:/i.test(link))
        link = encodeURI('https:' + link);
    return link;
}
